@@ -74,6 +74,7 @@ add_clicked_cb (GtkWidget  *widget,
 	char     *archive_name_utf8;
 	char     *archive_name;
 	char     *archive_dir;
+	char     *archive_name_test;
 	gboolean  do_not_add = FALSE;
 
 	data->add_clicked = TRUE;
@@ -88,16 +89,46 @@ add_clicked_cb (GtkWidget  *widget,
 
 	/* check whether the user entered an archive name. */
 
+	archive_name_test = remove_ending_separator (archive_name);
+	if (path_is_dir (archive_name_test)) {
+		GtkWidget  *d;
+
+		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+					     GTK_DIALOG_DESTROY_WITH_PARENT,
+					     GTK_STOCK_DIALOG_ERROR,
+					     _("Could not create the archive"),
+					     _("You have to specify an archive name."),
+					     GTK_STOCK_OK, GTK_RESPONSE_OK,
+					     NULL);
+		gtk_dialog_run (GTK_DIALOG (d));
+		gtk_widget_destroy (GTK_WIDGET (d));
+		g_free (archive_name);
+		g_free (archive_name_test);
+
+		return;
+	}
+
+	/* if the user do not specify an extension use tgz as default */
+	if (strchr (archive_name, '.') == NULL) {
+		char *new_archive_name;
+		new_archive_name = g_strconcat (archive_name, ".tgz", NULL);
+		g_free (archive_name);
+		archive_name = new_archive_name;
+	}
+
 	if (! fr_archive_utils__file_is_archive (archive_name)) {
 		GtkWidget  *d;
 
-		d = gtk_message_dialog_new (GTK_WINDOW (window->app),
-					    GTK_DIALOG_DESTROY_WITH_PARENT,
-					    GTK_MESSAGE_ERROR,
-					    GTK_BUTTONS_CLOSE,
-					    _("You have to specify an archive name."));
+		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+					     GTK_DIALOG_MODAL,
+					     GTK_STOCK_DIALOG_ERROR,
+					     _("Could not create the archive"),
+					     _("Archive type not supported."),
+					     GTK_STOCK_OK, GTK_RESPONSE_CANCEL,
+					     NULL);
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (GTK_WIDGET (d));
+		g_free (archive_name);
 
 		return;
 	}
@@ -113,6 +144,7 @@ add_clicked_cb (GtkWidget  *widget,
 					     GTK_DIALOG_MODAL,
 					     GTK_STOCK_DIALOG_QUESTION,
 					     _("Destination folder does not exist.  Do you want to create it?"),
+					     NULL,
 					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					     _("Create _Folder"), GTK_RESPONSE_YES,
 					     NULL);
@@ -126,14 +158,19 @@ add_clicked_cb (GtkWidget  *widget,
 	if (! do_not_add && ! ensure_dir_exists (archive_dir, 0755)) {
 		GtkWidget  *d;
 		const char *error;
+		char       *message;
 
 		error = gnome_vfs_result_to_string (gnome_vfs_result_from_errno ());
-		
-		d = gtk_message_dialog_new (GTK_WINDOW (window->app),
-					    GTK_DIALOG_DESTROY_WITH_PARENT,
-					    GTK_MESSAGE_ERROR,
-					    GTK_BUTTONS_CLOSE,
-					    _("Could not create the destination folder: %s.\nAddition not performed."), error);
+		message = g_strdup_printf (_("Could not create the destination folder: %s."), error);
+		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+					     GTK_DIALOG_DESTROY_WITH_PARENT,
+					     GTK_STOCK_DIALOG_ERROR,
+					     _("Addition not performed"),
+					     message,
+					     GTK_STOCK_OK, GTK_RESPONSE_CANCEL,
+					     NULL);
+		g_free (message);
+
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (GTK_WIDGET (d));
 		g_free (archive_dir);
@@ -147,11 +184,13 @@ add_clicked_cb (GtkWidget  *widget,
 	if (do_not_add) {
 		GtkWidget *d;
 
-		d = gtk_message_dialog_new (GTK_WINDOW (window->app),
-					    GTK_DIALOG_DESTROY_WITH_PARENT,
-					    GTK_MESSAGE_ERROR,
-					    GTK_BUTTONS_CLOSE,
-					    _("Addition not performed."));
+		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+					     GTK_DIALOG_DESTROY_WITH_PARENT,
+					     GTK_STOCK_DIALOG_ERROR,
+					     _("Addition not performed"),
+					     NULL,
+					     GTK_STOCK_OK, GTK_RESPONSE_CANCEL,
+					     NULL);
 		gtk_dialog_run (GTK_DIALOG (d));
 		g_free (archive_name);
 		gtk_widget_destroy (GTK_WIDGET (d));
@@ -173,7 +212,7 @@ add_clicked_cb (GtkWidget  *widget,
 						   FR_BATCH_ACTION_ADD,
 						   path_list_dup (data->file_list),
 						   (GFreeFunc) path_list_free);
-		window_archive_open (window, archive_name);
+		window_archive_open (window, archive_name, GTK_WINDOW (window->app));
 	}
 
 	g_free (archive_name);
