@@ -20,18 +20,13 @@
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  */
 
-#ifdef HAVE_FNMATCH
-#include <fnmatch.h>
-#endif /* HAVE_FNMATCH */
 #include <string.h>
 #include <glib.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include "file-utils.h"
 #include "file-list.h"
+#include "utf8-fnmatch.h"
 
-#ifndef HAVE_FNMATCH
-#include "fnmatch.h"
-#endif /* ! HAVE_FNMATCH */
 
 #define SPECIAL_DIR(x) (! strcmp (x, "..") || ! strcmp (x, "."))
 
@@ -86,6 +81,8 @@ filter_apply (Filter     *filter,
 	      const char *name)
 {
 	const char *file_name;
+	char       *utf8_name;
+	gboolean    retval;
 
         g_return_val_if_fail (filter != NULL, FALSE);
         g_return_val_if_fail (name != NULL, FALSE);
@@ -100,7 +97,11 @@ filter_apply (Filter     *filter,
 	    && (name[strlen (name) - 1] == '~'))
 		return FALSE;
 
-        return match_patterns (filter->patterns, file_name);
+	utf8_name = g_locale_to_utf8 (file_name, -1, NULL, NULL, NULL);
+	retval = match_patterns (filter->patterns, utf8_name, filter->fnmatch_flags);
+	g_free (utf8_name);
+
+        return retval;
 }
 
 
