@@ -25,6 +25,7 @@
 #include <time.h>
 
 #include <glib.h>
+#include <gnome.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
 
@@ -90,64 +91,15 @@ mktime_from_string (char *date_s,
 }
 
 
-static char *
-eat_spaces (char *line)
-{
-	while ((*line == ' ') && (*line != 0))
-		line++;
-	return line;
-}
-
-
-static char **
-split_line (char *line, 
-	    int   n_fields)
-{
-	char **fields;
-	char  *scan, *field_end;
-	int    i;
-
-	fields = g_new0 (char *, n_fields + 1);
-	fields[n_fields + 1] = NULL;
-
-	scan = eat_spaces (line);
-	for (i = 0; i < n_fields; i++) {
-		field_end = strchr (scan, ' ');
-		fields[i] = g_strndup (scan, field_end - scan);
-		scan = eat_spaces (field_end);
-	}
-
-	return fields;
-}
-
-
-static char *
-get_last_field (char *line)
-{
-	int   i;
-	char *field;
-	int   n = 8;
-
-	n--;
-	field = eat_spaces (line);
-	for (i = 0; i < n; i++) {
-		field = strchr (field, ' ');
-		field = eat_spaces (field);
-	}
-
-	return field;
-}
-
-
 static void
 list__process_line (char     *line, 
 		    gpointer  data)
 {
-	FileData   *fdata;
-	FRCommand  *comm = FR_COMMAND (data);
-	char      **fields;
-	char       *name_field;
-	gint        line_l;
+	FileData    *fdata;
+	FRCommand   *comm = FR_COMMAND (data);
+	char       **fields;
+	const char  *name_field;
+	gint         line_l;
 
 	g_return_if_fail (line != NULL);
 
@@ -175,7 +127,7 @@ list__process_line (char     *line,
 
 	/* Full path */
 
-	name_field = get_last_field (line);
+	name_field = get_last_field (line, 8);
 
 	if (*name_field == '/') {
 		fdata->full_path = g_strdup (name_field);
@@ -218,6 +170,25 @@ fr_command_zip_list (FRCommand *comm)
 }
 
 
+static void
+process_line__common (char     *line, 
+		      gpointer  data)
+{
+	FRCommand  *comm = FR_COMMAND (data);
+
+	if (line == NULL)
+		return;
+
+	fr_command_message (comm, line);
+
+	if (comm->n_files != 0) {
+		double fraction = (double) comm->n_file++ / comm->n_files;
+		fr_command_progress (comm, fraction);
+	}
+
+}
+
+
 static void
 fr_command_zip_add (FRCommand     *comm,
 		    GList         *file_list,
@@ -228,6 +199,10 @@ fr_command_zip_add (FRCommand     *comm,
 {
 	GList *scan;
 
+	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+				      process_line__common,
+				      comm);
+
 	fr_process_begin_command (comm->process, "zip");
 
 	if (base_dir != NULL) 
@@ -270,6 +245,10 @@ fr_command_zip_delete (FRCommand *comm,
 {
 	GList *scan;
 
+	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+				      process_line__common,
+				      comm);
+
 	fr_process_begin_command (comm->process, "zip");
 	fr_process_add_arg (comm->process, "-d");
 	fr_process_add_arg (comm->process, comm->e_filename);
@@ -291,6 +270,10 @@ fr_command_zip_extract (FRCommand  *comm,
 {
 	GList *scan;
 
+	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+				      process_line__common,
+				      comm);
+
 	fr_process_begin_command (comm->process, "unzip");
 	
 	if (dest_dir != NULL) {
