@@ -3,7 +3,7 @@
 /*
  *  File-Roller
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <gnome.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include "main.h"
 #include "gtk-utils.h"
 #include "window.h"
@@ -105,6 +106,7 @@ typedef struct {
 
 FileTypeDescription type_desc[] = { 
 	{ N_("Automatic"),                             NULL},
+	{ N_("Arj (.arj)"),                            ".arj" },
 	{ N_("Ear (.ear)"),                            ".ear" },
 	{ N_("Jar (.jar)"),                            ".jar" },
 	{ N_("Lha (.lzh)"),                            ".lzh" },
@@ -129,11 +131,19 @@ get_full_path (GtkWidget *file_sel)
 	GtkWidget   *opt_menu;
 	char        *full_path;
 	const char  *path;
+	const char  *filename;
 	int          file_type_idx;
 
 	opt_menu = g_object_get_data (G_OBJECT (file_sel), "fr_opt_menu");
 	path = gtk_file_selection_get_filename (GTK_FILE_SELECTION (file_sel));
 
+	if ((path == NULL) || (*path == 0))
+		return NULL;
+
+	filename = file_name_from_path (path);
+	if ((filename == NULL) || (*filename == 0))
+		return NULL;
+	
 	file_type_idx = opt_menu_get_active_idx (opt_menu);
 	if (file_type_idx > 0) 
 		full_path = g_strconcat (path, 
@@ -157,9 +167,22 @@ new_file_ok_cb (GtkWidget *w,
 	window = g_object_get_data (G_OBJECT (file_sel), "fr_window");
 
 	path = get_full_path (file_sel);
-        if (path == NULL) {
-		gtk_widget_destroy (file_sel);
-                return;
+
+	if ((path == NULL) || (*path == 0)) {
+		GtkWidget *dialog;
+
+		g_free (path);
+
+		dialog = _gtk_message_dialog_new (GTK_WINDOW (file_sel),
+						  GTK_DIALOG_DESTROY_WITH_PARENT,
+						  GTK_STOCK_DIALOG_ERROR,
+						  _("Could not create the archive"),
+						  _("You have to specify an archive name."),
+						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  NULL);
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (GTK_WIDGET (dialog));
+		return;
 	}
 	
 	dir = remove_level_from_path (path);
@@ -169,29 +192,41 @@ new_file_ok_cb (GtkWidget *w,
 		g_free (dir);
 		g_free (path);
 
-		dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
-						 GTK_DIALOG_DESTROY_WITH_PARENT,
-						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_CLOSE,
-						 _("You don't have permission to create an archive in this folder"));
+		dialog = _gtk_message_dialog_new (GTK_WINDOW (file_sel),
+						  GTK_DIALOG_DESTROY_WITH_PARENT,
+						  GTK_STOCK_DIALOG_ERROR,
+						  _("Could not create the archive"),
+						  _("You don't have permission to create an archive in this folder"),
+						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  NULL);
+
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 		return;
 	}
 	g_free (dir);
 
+	/* if the user do not specify an extension use tgz as default */
+	if (strchr (path, '.') == NULL) {
+		char *new_path;
+		new_path = g_strconcat (path, ".tgz", NULL);
+		g_free (path);
+		path = new_path;
+	}
+
 #ifdef DEBUG
 	g_print ("create %s\n", path); 
 #endif
 
 	if (path_is_file (path)) {
 		GtkWidget *dialog;
-		int r;
+		int        r;
 
-		dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+		dialog = _gtk_message_dialog_new (GTK_WINDOW (file_sel),
 						  GTK_DIALOG_MODAL,
 						  GTK_STOCK_DIALOG_QUESTION,
-						  _("Archive already exists.  Do you want to overwrite it?"),
+						  _("The archive already exists.  Do you want to overwrite it?"),
+						  NULL,
 						  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 						  _("Overwrite"), GTK_RESPONSE_YES,
 						  NULL);
@@ -206,11 +241,13 @@ new_file_ok_cb (GtkWidget *w,
 
 		if (unlink (path) != 0) {
 			GtkWidget *dialog;
-			dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
-							 GTK_DIALOG_DESTROY_WITH_PARENT,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_CLOSE,
-							 _("Could not delete old archive."));
+			dialog = _gtk_message_dialog_new (GTK_WINDOW (file_sel),
+							  GTK_DIALOG_DESTROY_WITH_PARENT,
+							  GTK_STOCK_DIALOG_ERROR,
+							  _("Could not delete the old archive."),
+							  NULL,
+							  GTK_STOCK_OK, GTK_RESPONSE_OK,
+							  NULL);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (GTK_WIDGET (dialog));
 			return;
@@ -297,6 +334,168 @@ new_archive_cb (GtkWidget *widget,
 }
 
 
+/* -- save as archive -- */
+
+
+static void
+save_file_destroy_cb (GtkWidget *w,
+		      GtkWidget *file_sel)
+{
+}
+
+
+static void 
+save_file_ok_cb (GtkWidget *w,
+		 GtkWidget *file_sel)
+{
+	FRWindow *window;
+	char     *path;
+	char     *dir;
+
+	window = g_object_get_data (G_OBJECT (file_sel), "fr_window");
+
+	path = get_full_path (file_sel);
+
+	if ((path == NULL) || (*path == 0)) {
+		GtkWidget *dialog;
+
+		g_free (path);
+
+		dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+						  GTK_DIALOG_DESTROY_WITH_PARENT,
+						  GTK_STOCK_DIALOG_ERROR,
+						  _("Could not save the archive"),
+						  _("You have to specify an archive name."),
+						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  NULL);
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (GTK_WIDGET (dialog));
+		return;
+	}
+	
+	dir = remove_level_from_path (path);
+	if (access (dir, R_OK | W_OK | X_OK) != 0) {
+		GtkWidget *dialog;
+
+		g_free (dir);
+		g_free (path);
+
+		dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+						  GTK_DIALOG_DESTROY_WITH_PARENT,
+						  GTK_STOCK_DIALOG_ERROR,
+						  _("Could not save the archive"),
+						  _("You don't have permission to create an archive in this folder"),
+						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  NULL);
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (GTK_WIDGET (dialog));
+		return;
+	}
+	g_free (dir);
+
+#ifdef DEBUG
+	g_print ("save as %s\n", path); 
+#endif
+
+	if (path_is_file (path)) {
+		GtkWidget *dialog;
+		int r;
+
+		dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+						  GTK_DIALOG_MODAL,
+						  GTK_STOCK_DIALOG_QUESTION,
+						  _("The archive already exists.  Do you want to overwrite it?"),
+						  NULL,
+						  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						  _("Overwrite"), GTK_RESPONSE_YES,
+						  NULL);
+
+		r = gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (GTK_WIDGET (dialog));
+
+		if (r != GTK_RESPONSE_YES) {
+			g_free (path);
+			return;
+		}
+
+		if (unlink (path) != 0) {
+			GtkWidget *dialog;
+			dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+							  GTK_DIALOG_DESTROY_WITH_PARENT,
+							  GTK_STOCK_DIALOG_ERROR,
+							  _("Could not delete the old archive."),
+							  NULL,
+							  GTK_STOCK_OK, GTK_RESPONSE_OK,
+							  NULL);
+			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_widget_destroy (GTK_WIDGET (dialog));
+			return;
+		}
+	} 
+
+	window_archive_save_as (window, path);
+	gtk_widget_destroy (file_sel);
+	g_free (path);
+}
+
+
+void
+save_as_archive_cb (GtkWidget *widget, 
+		    void *data)
+{
+	FRWindow  *window = data;
+	GtkWidget *file_sel;
+	GtkWidget *hbox;
+	GtkWidget *opt_menu;
+	GtkWidget *menu;
+	char      *dir;
+
+	file_sel = gtk_file_selection_new (_("Save Archive"));
+
+	dir = g_strconcat (window->open_default_dir, "/", NULL);
+	gtk_file_selection_set_filename (GTK_FILE_SELECTION (file_sel), dir);
+	g_free (dir);
+
+	/**/
+
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (GTK_FILE_SELECTION (file_sel)->action_area), hbox, TRUE, TRUE, 0);
+
+	gtk_box_pack_start (GTK_BOX (hbox), 
+			    gtk_label_new (_("Archive type:")),
+			    FALSE, FALSE, 0);
+
+	opt_menu = gtk_option_menu_new ();
+	menu = build_file_type_menu (window);
+        gtk_option_menu_set_menu (GTK_OPTION_MENU (opt_menu), menu);
+	gtk_widget_show (opt_menu);
+	gtk_box_pack_start (GTK_BOX (hbox), opt_menu, FALSE, FALSE, 12);
+	
+	/**/
+
+	g_object_set_data (G_OBJECT (file_sel), "fr_window", window);
+	g_object_set_data (G_OBJECT (file_sel), "fr_opt_menu", opt_menu);
+	
+	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (file_sel)->ok_button),
+			  "clicked", 
+			  G_CALLBACK (save_file_ok_cb), 
+			  file_sel);
+
+	g_signal_connect_swapped (G_OBJECT (GTK_FILE_SELECTION (file_sel)->cancel_button),
+				  "clicked", 
+				  G_CALLBACK (gtk_widget_destroy),
+				  G_OBJECT (file_sel));
+
+	g_signal_connect (G_OBJECT (file_sel),
+			  "destroy", 
+			  G_CALLBACK (save_file_destroy_cb),
+			  file_sel);
+
+	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
+	gtk_widget_show_all (file_sel);
+}
+
+
 /* -- open archive -- */
 
 
@@ -311,8 +510,8 @@ static void
 open_file_ok_cb (GtkWidget *w,
                  GtkWidget *file_sel)
 {
-	FRWindow *window;
-	const gchar *path;
+	FRWindow   *window;
+	const char *path;
 
 	window = g_object_get_data (G_OBJECT (file_sel), "fr_window");
 	path = gtk_file_selection_get_filename (GTK_FILE_SELECTION (file_sel));
@@ -320,9 +519,8 @@ open_file_ok_cb (GtkWidget *w,
         if (path == NULL)
                 return;
 
-	window_archive_open (window, path);
-
-	gtk_widget_destroy (file_sel);
+	if (window_archive_open (window, path, GTK_WINDOW (file_sel)))
+		gtk_widget_destroy (file_sel);
 }
 
 
@@ -376,6 +574,7 @@ close_archive_cb (GtkWidget *widget,
 typedef struct {
 	FRWindow  *window;
 	gboolean   copy;
+	gboolean   overwrite;
 	GtkWidget *file_sel;
 } CopyMoveData;
 
@@ -389,36 +588,41 @@ file_sel_destroy_cb (GtkWidget    *w,
 
 
 static void 
-copy_archive_ok_cb (GtkWidget    *w,
-		    CopyMoveData *data)
+copy_or_move_archive_ok_cb (GtkWidget    *w,
+			    CopyMoveData *data)
 {
-	FRWindow   *window;
-	const char *path;
-	char       *new_filename;
+	FRWindow    *window;
+	const char  *path;
+	const char  *filename;
+	char        *folder;
+	char        *new_path;
 
 	gtk_widget_hide (data->file_sel);
 
 	window = data->window;
 	path = gtk_file_selection_get_filename (GTK_FILE_SELECTION (data->file_sel));
 
-	if (path == NULL) {
+	if ((path == NULL) || (*path == 0)) {
                 gtk_widget_destroy (data->file_sel);
 		return;
 	}
 
-	if (path[strlen (path) - 1] == '/')
-		new_filename = g_strconcat (path, file_name_from_path (window->archive_filename), NULL);
-	else
-		new_filename = g_strconcat (path, "/", file_name_from_path (window->archive_filename), NULL);
+	filename = file_name_from_path (path);
+	if ((filename == NULL) || (*filename == 0))
+		filename = file_name_from_path (window->archive_filename);
+	folder = remove_level_from_path (path);
+	new_path = g_build_filename (folder, filename, NULL);
+	g_free (folder);
 
-	if (path_is_file (new_filename)) {
+	if (path_is_file (new_path)) {
 		GtkWidget *d;
 		int        r;
 
 		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
 					     GTK_DIALOG_MODAL,
 					     GTK_STOCK_DIALOG_QUESTION,
-					     _("Archive already exists.  Do you want to overwrite it?"),
+					     _("The archive already exists.  Do you want to overwrite it?"),
+					     NULL,
 					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					     _("Overwrite"), GTK_RESPONSE_YES,
 					     NULL);
@@ -427,7 +631,7 @@ copy_archive_ok_cb (GtkWidget    *w,
 		gtk_widget_destroy (GTK_WIDGET (d));
 		
 		if (r != GTK_RESPONSE_YES) {
-			g_free (new_filename);
+			g_free (new_path);
 			gtk_widget_destroy (data->file_sel);
 			return;
 		}
@@ -435,44 +639,49 @@ copy_archive_ok_cb (GtkWidget    *w,
 	
 	if (data->copy) {
 #ifdef DEBUG
-		g_print ("cp %s %s\n", window->archive_filename, new_filename);
+		g_print ("cp %s %s\n", window->archive_filename, new_path);
 #endif
-		if (! file_copy (window->archive_filename, new_filename)) {
+		if (! file_copy (window->archive_filename, new_path)) {
 			GtkWidget *dialog;
-			dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
-							 GTK_DIALOG_DESTROY_WITH_PARENT,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_CLOSE,
-							 _("Could not copy archive"));
+			dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+							  GTK_DIALOG_DESTROY_WITH_PARENT,
+							  GTK_STOCK_DIALOG_ERROR,
+							  _("Could not copy the archive"),
+							  NULL,
+							  GTK_STOCK_OK, GTK_RESPONSE_OK,
+							  NULL);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
 		}
 	} else {
 #ifdef DEBUG
-		g_print ("mv %s %s\n", window->archive_filename, new_filename);
+		g_print ("mv %s %s\n", window->archive_filename, new_path);
 #endif
-		if (file_move (window->archive_filename, new_filename)) 
-			window_archive_rename (window, new_filename);
+		if (file_move (window->archive_filename, new_path)) 
+			window_archive_rename (window, new_path);
 		else {
 			GtkWidget *dialog;
-			dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
-							 GTK_DIALOG_DESTROY_WITH_PARENT,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_CLOSE,
-							 _("Could not move archive"));
+			dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+							  GTK_DIALOG_DESTROY_WITH_PARENT,
+							  GTK_STOCK_DIALOG_ERROR,
+							  _("Could not move the archive"),
+							  NULL,
+							  GTK_STOCK_OK, GTK_RESPONSE_OK,
+							  NULL);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
 		}
 	}
 
-	g_free (new_filename);
+	g_free (new_path);
 	gtk_widget_destroy (data->file_sel);
 }
 
 
 static void
 copy_or_move_archive (FRWindow *window, 
-		      gboolean  copy)
+		      gboolean  copy,
+		      gboolean  overwrite)
 {
 	GtkWidget    *file_sel;
 	char         *dir;
@@ -481,7 +690,8 @@ copy_or_move_archive (FRWindow *window,
 	data = g_new (CopyMoveData, 1);
 	data->window = window;
 	data->copy = copy;
-	data->file_sel = file_sel = gtk_file_selection_new (copy ? _("Copy archive") : _("Move archive"));
+	data->overwrite = overwrite;
+	data->file_sel = file_sel = gtk_file_selection_new (copy ? _("Copy Archive") : _("Move Archive"));
 
 	dir = g_strconcat (window->open_default_dir, "/", NULL);
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (file_sel), dir);
@@ -492,7 +702,7 @@ copy_or_move_archive (FRWindow *window,
 
 	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (file_sel)->ok_button),
 			  "clicked", 
-			  G_CALLBACK (copy_archive_ok_cb), 
+			  G_CALLBACK (copy_or_move_archive_ok_cb), 
 			  data);
 
 	g_signal_connect_swapped (G_OBJECT (GTK_FILE_SELECTION (file_sel)->cancel_button),
@@ -514,7 +724,7 @@ void
 move_archive_cb (GtkWidget *widget, 
 		 void      *data)
 {
-	copy_or_move_archive ((FRWindow *) data, FALSE);
+	copy_or_move_archive ((FRWindow *) data, FALSE, FALSE);
 }
 
 
@@ -522,7 +732,7 @@ void
 copy_archive_cb (GtkWidget *widget, 
 		 void      *data)
 {
-	copy_or_move_archive ((FRWindow *) data, TRUE);
+	copy_or_move_archive ((FRWindow *) data, TRUE, FALSE);
 }
 
 
@@ -559,6 +769,7 @@ rename_archive_cb (GtkWidget *widget,
 	utf8_string = _gtk_request_dialog_run (GTK_WINDOW (window->app),
 					       (GTK_DIALOG_DESTROY_WITH_PARENT 
 						| GTK_DIALOG_MODAL),
+					       _("Rename Archive"),
 					       _("New archive name (without extension)"),
 					       utf8_old_string,
 					       1024,
@@ -588,7 +799,8 @@ rename_archive_cb (GtkWidget *widget,
 		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
 					     GTK_DIALOG_MODAL,
 					     GTK_STOCK_DIALOG_QUESTION,
-					     _("Archive already exists.  Do you want to overwrite it?"),
+					     _("The archive already exists.  Do you want to overwrite it?"),
+					     NULL,
 					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					     _("Overwrite"), GTK_RESPONSE_YES,
 					     NULL);
@@ -616,31 +828,93 @@ rename_archive_cb (GtkWidget *widget,
 /* -- delete archive -- */
 
 
+void delete_archive__step2 (GnomeVFSResult result,
+			    gpointer       data)
+{
+	FRWindow *window = data;
+	if (result == GNOME_VFS_OK)
+		window_archive_close (window);
+}
+
+
+static char *
+get_trash_path (const char *filename)
+{
+	char        *e_filename;
+	GnomeVFSURI *uri, *trash_uri;
+
+	e_filename = gnome_vfs_escape_path_string (filename);
+	uri = gnome_vfs_uri_new (e_filename);
+	g_free (e_filename);
+
+	gnome_vfs_find_directory (uri, 
+				  GNOME_VFS_DIRECTORY_KIND_TRASH,
+				  &trash_uri, 
+				  TRUE,
+				  TRUE,
+				  0777);
+	gnome_vfs_uri_unref (uri);
+
+	if (trash_uri == NULL)
+		return NULL;
+	else {
+		char *trash_path;
+		trash_path = gnome_vfs_uri_to_string (trash_uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
+		gnome_vfs_uri_unref (trash_uri);
+		return trash_path;
+	}
+}
+
+
 void
 delete_archive_cb (GtkWidget *widget, 
 		   void *data)
 {
 	FRWindow *window = data;
-	GtkWidget *dialog;
-	int r;
+	char     *trash_path;
 
-	dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
-					  GTK_DIALOG_MODAL,
-					  GTK_STOCK_DIALOG_QUESTION,
-					  _("Archive will be deleted, are you sure?"),
-					  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					  GTK_STOCK_DELETE, GTK_RESPONSE_YES,
-					  NULL);
-
-	r = gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
-	if (r == GTK_RESPONSE_YES) {
 #ifdef DEBUG
-		g_print ("rm %s\n", window->archive->filename);
+	g_print ("rm %s\n", window->archive->filename);
 #endif
-		if (unlink (window->archive->filename) == 0)
+
+	trash_path = get_trash_path (window->archive->filename);
+
+	if (trash_path == NULL) {
+		GtkWidget *d;
+		int        r;
+		d = _gtk_yesno_dialog_new (GTK_WINDOW (window->app),
+					   GTK_DIALOG_MODAL,
+					   _("The archive cannot be moved to the Trash. Do you want to delete it permanently?"),
+					   GTK_STOCK_NO,
+					   GTK_STOCK_DELETE);
+		
+		r = gtk_dialog_run (GTK_DIALOG (d));
+		gtk_widget_destroy (GTK_WIDGET (d));
+		
+		if (r == GTK_RESPONSE_YES) {
+			if (unlink (window->archive->filename) == 0)
+				window_archive_close (window);
+		}
+		
+	} else {
+		const char *filename;
+		char       *dest_filename;
+		
+		filename = file_name_from_path (window->archive->filename);
+		if (trash_path[strlen (trash_path) - 1] == '/')
+			dest_filename = g_strconcat (trash_path, 
+						     filename,
+						     NULL);
+		else
+			dest_filename = g_strconcat (trash_path, 
+						     "/", 
+						     filename,
+						     NULL);
+		
+		if (file_move (window->archive_filename, dest_filename))
 			window_archive_close (window);
 	}
+	g_free (trash_path);
 }
 
 
@@ -746,11 +1020,13 @@ manual_cb (GtkWidget *widget,
         if (err != NULL) {
                 GtkWidget *dialog;
                 
-                dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
-                                                 GTK_DIALOG_DESTROY_WITH_PARENT,                                                 GTK_MESSAGE_ERROR,
-                                                 GTK_BUTTONS_CLOSE,
-                                                 _("Could not display help: %s"),
-                                                 err->message);
+                dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+						  GTK_DIALOG_DESTROY_WITH_PARENT, 
+						  GTK_STOCK_DIALOG_ERROR,
+						  _("Could not display help"),
+						  err->message,
+						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  NULL);
                 
                 g_signal_connect (G_OBJECT (dialog), "response",
                                   G_CALLBACK (gtk_widget_destroy),
@@ -776,7 +1052,9 @@ about_cb (GtkWidget *widget,
 		"Paolo Bacchilega <paolo.bacch@tin.it>", NULL
 	};
 	const char       *documenters [] = {
-		"Alexander Kirillov", NULL
+		"Alexander Kirillov", 
+		"Breda McColgan",
+		NULL
 	};
 	const char       *translator_credits = _("translator_credits");
 
@@ -917,11 +1195,19 @@ stop_cb (GtkWidget *widget,
 {
 	FRWindow *window = data;
 
+	if (! window->stoppable)
+		return;
+
 	if (window->vd_handle != NULL) {
 		visit_dir_async_interrupt (window->vd_handle, 
 					   stop__step2, 
 					   window);
 		window->vd_handle = NULL;
+		window_pop_message (window);
+		window_stop_activity_mode (window);
+
+		if (window->convert_data.converting) 
+			window_convert_data_free (window);
 
 	} else
 		stop__step2 (window);
@@ -955,7 +1241,7 @@ last_output_cb (GtkWidget *widget,
 		void      *data)
 {
 	FRWindow *window = data;
-	window_view_last_output (window);
+	window_view_last_output (window, _("Last Output"));
 }
 
 
