@@ -3,7 +3,7 @@
 /*
  *  File-Roller
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,12 +27,9 @@
 #include "typedefs.h"
 #include "window.h"
 
-#define PREF_INSTALL_SCRIPTS       "/apps/file-roller/general/install_nautilus_scripts"
-
 #define PREF_LIST_SORT_METHOD      "/apps/file-roller/listing/sort_method"
 #define PREF_LIST_SORT_TYPE        "/apps/file-roller/listing/sort_type"
 #define PREF_LIST_MODE             "/apps/file-roller/listing/list_mode"
-#define PREF_LIST_SHOW_NAME        "/apps/file-roller/listing/show_name"
 #define PREF_LIST_SHOW_TYPE        "/apps/file-roller/listing/show_type"
 #define PREF_LIST_SHOW_SIZE        "/apps/file-roller/listing/show_size"
 #define PREF_LIST_SHOW_TIME        "/apps/file-roller/listing/show_time"
@@ -46,6 +43,7 @@
 #define PREF_EDIT_EDITORS          "/apps/file-roller/general/editors"
 #define PREF_EXTRACT_VIEW_FOLDER   "/apps/file-roller/general/view_folder_after_extraction"
 #define PREF_ADD_COMPRESSION_LEVEL "/apps/file-roller/general/compression_level"
+#define PREF_MIGRATE_DIRECTORIES   "/apps/file-roller/general/migrate_directories"
 
 #define PREF_DESKTOP_ICON_THEME         "/desktop/gnome/file_views/icon_theme"
 #define PREF_DESKTOP_MENUS_HAVE_TEAROFF "/desktop/gnome/interface/menus_have_tearoff"
